@@ -27,7 +27,7 @@
 #include "kpEffectHSVCommand.h"
 #include "imagelib/effects/kpEffectHSV.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 //---------------------------------------------------------------------
 
