@@ -31,7 +31,7 @@
 #include "kpEffectBlurSharpen.h"
 #include "blitz.h"
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 #include "pixmapfx/kpPixmapFX.h"
 
@@ -59,13 +59,11 @@
 //
 
 
-static QImage BlurQImage (const QImage qimage_, int strength)
+static QImage BlurQImage(const QImage &qimage, int strength)
 {
-    QImage qimage = qimage_;
     if (strength == 0)
         return qimage;
 
-
     // The numbers that follow were picked by experimentation to try to get
     // an effect linearly proportional to <strength> and at the same time,
     // be fast enough.
@@ -80,16 +78,13 @@ static QImage BlurQImage (const QImage qimage_, int strength)
         (kpEffectBlurSharpen::MaxStrength - 1);
 
 #if DEBUG_KP_EFFECT_BLUR_SHARPEN
-    kDebug () << "kpEffectBlurSharpen.cpp:BlurQImage(strength=" << strength << ")"
+    qCDebug(kpLogImagelib) << "kpEffectBlurSharpen.cpp:BlurQImage(strength=" << strength << ")"
                << " radius=" << radius
                << endl;
 #endif
 
-
-    qimage = Blitz::blur (qimage, qRound (radius));
-
-
-    return qimage;
+    QImage img(qimage);
+    return Blitz::blur(img, qRound(radius));
 }
 
 //---------------------------------------------------------------------
@@ -149,7 +144,7 @@ static QImage SharpenQImage (const QImage &qimage_, int strength)
 #endif
 
 #if DEBUG_KP_EFFECT_BLUR_SHARPEN
-    kDebug () << "kpEffectBlurSharpen.cpp:SharpenQImage(strength=" << strength << ")"
+    qCDebug(kpLogImagelib) << "kpEffectBlurSharpen.cpp:SharpenQImage(strength=" << strength << ")"
                << " radius=" << radius
                << " sigma=" << sigma
                << " repeat=" << repeat
@@ -160,11 +155,11 @@ static QImage SharpenQImage (const QImage &qimage_, int strength)
     for (int i = 0; i < repeat; i++)
     {
     #if DEBUG_KP_EFFECT_BLUR_SHARPEN
-	QTime timer; timer.start ();
+        QTime timer; timer.start ();
     #endif
         qimage = Blitz::gaussianSharpen (qimage, radius, sigma);
     #if DEBUG_KP_EFFECT_BLUR_SHARPEN
-        kDebug () << "\titeration #" + QString::number (i)
+        qCDebug(kpLogImagelib) << "\titeration #" + QString::number (i)
                   << ": " + QString::number (timer.elapsed ()) << "ms" << endl;
     #endif
     }
@@ -180,7 +175,7 @@ kpImage kpEffectBlurSharpen::applyEffect (const kpImage &image,
         Type type, int strength)
 {
 #if DEBUG_KP_EFFECT_BLUR_SHARPEN
-    kDebug () << "kpEffectBlurSharpen::applyEffect(image.rect=" << image.rect ()
+    qCDebug(kpLogImagelib) << "kpEffectBlurSharpen::applyEffect(image.rect=" << image.rect ()
               << ",type=" << int (type)
               << ",strength=" << strength
               << ")" << endl;
@@ -192,6 +187,11 @@ kpImage kpEffectBlurSharpen::applyEffect (const kpImage &image,
         return ::BlurQImage (image, strength);
     else if (type == Sharpen)
         return ::SharpenQImage (image, strength);
+    else if (type == MakeConfidential)
+    {
+        QImage img(image);
+        return Blitz::blur(img, qMin(20, img.width() / 2));
+    }
     else
       return kpImage();
 }
