@@ -56,7 +56,7 @@ kpToolSpraycan::kpToolSpraycan (kpToolEnvironment *environ, QObject *parent)
     : kpToolFlowBase (i18n ("Spraycan"), i18n ("Sprays graffiti"),
         Qt::Key_Y,
         environ, parent, "tool_spraycan"),
-    m_toolWidgetSpraycanSize(0)
+    m_toolWidgetSpraycanSize(nullptr)
 {
     m_timer = new QTimer (this);
     m_timer->setInterval (25/*ms*/);
@@ -94,7 +94,7 @@ void kpToolSpraycan::end ()
 
     disconnect (m_toolWidgetSpraycanSize, SIGNAL (spraycanSizeChanged (int)),
                 this, SLOT (slotSpraycanSizeChanged (int)));
-    m_toolWidgetSpraycanSize = 0;
+    m_toolWidgetSpraycanSize = nullptr;
 }
 
 
