@@ -51,7 +51,7 @@
 //---------------------------------------------------------------------
 
 kpToolWidgetBase::kpToolWidgetBase (QWidget *parent, const QString &name)
-    : QFrame(parent), m_baseWidget(0),
+    : QFrame(parent), m_baseWidget(nullptr),
       m_selectedRow(-1), m_selectedCol(-1)
 {
     setObjectName (name);
